@@ -31,8 +31,7 @@ import sys
 from datetime import datetime
 from typing import Generic, Iterator, Sequence, TypeVar, Union
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import AlarmTypeType, HistoryItemTypeType, ScanByType, StateValueType
 from .type_defs import (
@@ -72,7 +71,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class DescribeAlarmHistoryPaginator(Boto3Paginator):
+class DescribeAlarmHistoryPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators/#describealarmhistorypaginator)
@@ -87,7 +86,7 @@ class DescribeAlarmHistoryPaginator(Boto3Paginator):
         StartDate: Union[datetime, str] = ...,
         EndDate: Union[datetime, str] = ...,
         ScanBy: ScanByType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeAlarmHistoryOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
@@ -95,7 +94,7 @@ class DescribeAlarmHistoryPaginator(Boto3Paginator):
         """
 
 
-class DescribeAlarmsPaginator(Boto3Paginator):
+class DescribeAlarmsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators/#describealarmspaginator)
@@ -111,7 +110,7 @@ class DescribeAlarmsPaginator(Boto3Paginator):
         ParentsOfAlarmName: str = ...,
         StateValue: StateValueType = ...,
         ActionPrefix: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeAlarmsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
@@ -119,7 +118,7 @@ class DescribeAlarmsPaginator(Boto3Paginator):
         """
 
 
-class GetMetricDataPaginator(Boto3Paginator):
+class GetMetricDataPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators/#getmetricdatapaginator)
@@ -128,12 +127,12 @@ class GetMetricDataPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        MetricDataQueries: Sequence["MetricDataQueryTypeDef"],
+        MetricDataQueries: Sequence[MetricDataQueryTypeDef],
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
         ScanBy: ScanByType = ...,
-        LabelOptions: "LabelOptionsTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        LabelOptions: LabelOptionsTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetMetricDataOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
@@ -141,14 +140,14 @@ class GetMetricDataPaginator(Boto3Paginator):
         """
 
 
-class ListDashboardsPaginator(Boto3Paginator):
+class ListDashboardsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators/#listdashboardspaginator)
     """
 
     def paginate(
-        self, *, DashboardNamePrefix: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, DashboardNamePrefix: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDashboardsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
@@ -156,7 +155,7 @@ class ListDashboardsPaginator(Boto3Paginator):
         """
 
 
-class ListMetricsPaginator(Boto3Paginator):
+class ListMetricsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators/#listmetricspaginator)
@@ -167,9 +166,9 @@ class ListMetricsPaginator(Boto3Paginator):
         *,
         Namespace: str = ...,
         MetricName: str = ...,
-        Dimensions: Sequence["DimensionFilterTypeDef"] = ...,
+        Dimensions: Sequence[DimensionFilterTypeDef] = ...,
         RecentlyActive: Literal["PT3H"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListMetricsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
